/* collection-view.c generated by valac 0.20.1.16-ff48-dirty, the Vala compiler
 * generated from collection-view.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <clutter/clutter.h>
#include <libgd/gd.h>
#include <clutter-gtk/clutter-gtk.h>
#include <gtk/gtk.h>
#include <glib/gi18n-lib.h>
#include <stdlib.h>
#include <string.h>
#include <float.h>
#include <math.h>
#include <gdk/gdk.h>
#include <cairo.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>


#define BOXES_TYPE_SELECTION_CRITERIA (boxes_selection_criteria_get_type ())

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
typedef struct _BoxesCollectionViewPrivate BoxesCollectionViewPrivate;

#define BOXES_TYPE_CATEGORY (boxes_category_get_type ())
#define BOXES_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CATEGORY, BoxesCategory))
#define BOXES_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CATEGORY, BoxesCategoryClass))
#define BOXES_IS_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CATEGORY))
#define BOXES_IS_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CATEGORY))
#define BOXES_CATEGORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CATEGORY, BoxesCategoryClass))

typedef struct _BoxesCategory BoxesCategory;
typedef struct _BoxesCategoryClass BoxesCategoryClass;

#define BOXES_COLLECTION_VIEW_TYPE_MODEL_COLUMNS (boxes_collection_view_model_columns_get_type ())
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_CATEGORY_TYPE_KIND (boxes_category_kind_get_type ())

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;
#define _gtk_tree_path_free0(var) ((var == NULL) ? NULL : (var = (gtk_tree_path_free (var), NULL)))

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;
typedef struct _BoxesCategoryPrivate BoxesCategoryPrivate;
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())
#define _gtk_icon_info_free0(var) ((var == NULL) ? NULL : (var = (gtk_icon_info_free (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _Block11Data Block11Data;
typedef struct _Block12Data Block12Data;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_CLUTTER_WIDGET (boxes_clutter_widget_get_type ())
#define BOXES_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidget))
#define BOXES_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))
#define BOXES_IS_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_IS_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_CLUTTER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))

typedef struct _BoxesClutterWidget BoxesClutterWidget;
typedef struct _BoxesClutterWidgetClass BoxesClutterWidgetClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;
typedef struct _Block13Data Block13Data;

typedef enum  {
	BOXES_SELECTION_CRITERIA_ALL,
	BOXES_SELECTION_CRITERIA_NONE,
	BOXES_SELECTION_CRITERIA_RUNNING
} BoxesSelectionCriteria;

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesCollectionView {
	BoxesUI parent_instance;
	BoxesCollectionViewPrivate * priv;
	GdMainView* main_view;
};

struct _BoxesCollectionViewClass {
	BoxesUIClass parent_class;
};

struct _BoxesCollectionViewPrivate {
	GtkClutterActor* gtkactor;
	BoxesCategory* _category;
	GtkListStore* model;
	GtkTreeModelFilter* model_filter;
};

typedef enum  {
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SCREENSHOT = GD_MAIN_COLUMN_ICON,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_TITLE = GD_MAIN_COLUMN_PRIMARY_TEXT,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_INFO = GD_MAIN_COLUMN_SECONDARY_TEXT,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED = GD_MAIN_COLUMN_SELECTED,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM = GD_MAIN_COLUMN_LAST,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_LAST
} BoxesCollectionViewModelColumns;

typedef enum  {
	BOXES_CATEGORY_KIND_USER,
	BOXES_CATEGORY_KIND_NEW,
	BOXES_CATEGORY_KIND_FAVORITES,
	BOXES_CATEGORY_KIND_PRIVATE,
	BOXES_CATEGORY_KIND_SHARED
} BoxesCategoryKind;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesCategory {
	GObject parent_instance;
	BoxesCategoryPrivate * priv;
	gchar* name;
	BoxesCategoryKind kind;
};

struct _BoxesCategoryClass {
	GObjectClass parent_class;
};

struct _BoxesCollectionItem {
	BoxesUI parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	BoxesUIClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
	gboolean suspend_at_exit;
	gboolean deleted;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
};

struct _Block11Data {
	int _ref_count_;
	BoxesCollectionView * self;
	BoxesMachine* machine;
	GtkTreeIter iter;
	BoxesCollectionItem* item;
};

struct _Block12Data {
	int _ref_count_;
	BoxesCollectionView * self;
	GList* selected;
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	BoxesClutterWidget* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* searchbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
	BoxesCollectionView* view;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};

struct _Block13Data {
	int _ref_count_;
	BoxesCollectionView * self;
	BoxesSelectionCriteria selection;
};


static gpointer boxes_collection_view_parent_class = NULL;
extern BoxesApp* boxes_app_app;

GType boxes_selection_criteria_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
GType boxes_category_get_type (void) G_GNUC_CONST;
#define BOXES_COLLECTION_VIEW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewPrivate))
enum  {
	BOXES_COLLECTION_VIEW_DUMMY_PROPERTY,
	BOXES_COLLECTION_VIEW_ACTOR,
	BOXES_COLLECTION_VIEW_CATEGORY,
	BOXES_COLLECTION_VIEW_VISIBLE
};
static GType boxes_collection_view_model_columns_get_type (void) G_GNUC_UNUSED;
BoxesCollectionView* boxes_collection_view_new (void);
BoxesCollectionView* boxes_collection_view_construct (GType object_type);
BoxesUI* boxes_ui_construct (GType object_type);
GType boxes_category_kind_get_type (void) G_GNUC_CONST;
BoxesCategory* boxes_category_new (const gchar* name, BoxesCategoryKind kind);
BoxesCategory* boxes_category_construct (GType object_type, const gchar* name, BoxesCategoryKind kind);
void boxes_collection_view_set_category (BoxesCollectionView* self, BoxesCategory* value);
static void boxes_collection_view_setup_view (BoxesCollectionView* self);
GType boxes_app_get_type (void) G_GNUC_CONST;
static void __lambda56_ (BoxesCollectionView* self);
gboolean boxes_app_get_selection_mode (BoxesApp* self);
static void ___lambda56__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
void boxes_collection_view_get_item_pos (BoxesCollectionView* self, BoxesCollectionItem* item, gfloat* x, gfloat* y);
static GtkTreePath* boxes_collection_view_get_path_for_item (BoxesCollectionView* self, BoxesCollectionItem* item);
static void boxes_collection_view_real_ui_state_changed (BoxesUI* base);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
void boxes_fade_actor (ClutterActor* actor, guint opacity);
ClutterActor* boxes_ui_get_actor (BoxesUI* self);
static void boxes_collection_view_update_item_visible (BoxesCollectionView* self, BoxesCollectionItem* item);
GType boxes_machine_get_type (void) G_GNUC_CONST;
BoxesCategory* boxes_collection_view_get_category (BoxesCollectionView* self);
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle);
static void boxes_collection_view_update_screenshot (BoxesCollectionView* self, GtkTreeIter* iter);
GdkPixbuf* boxes_machine_get_pixbuf (BoxesMachine* self);
GIcon* boxes_create_symbolic_emblem (const gchar* name);
static void _vala_array_add1 (GIcon*** array, int* length, int* size, GIcon* value);
static void boxes_collection_view_append (BoxesCollectionView* self, const gchar* title, const gchar* info, BoxesCollectionItem* item, GtkTreeIter* result);
static GtkTreeIter* _gtk_tree_iter_dup (GtkTreeIter* self);
void boxes_collection_view_add_item (BoxesCollectionView* self, BoxesCollectionItem* item);
static Block11Data* block11_data_ref (Block11Data* _data11_);
static void block11_data_unref (void * _userdata_);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
const gchar* boxes_machine_get_info (BoxesMachine* self);
static void __lambda58_ (Block11Data* _data11_);
static void ___lambda58__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda59_ (Block11Data* _data11_);
static void ___lambda59__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda60_ (Block11Data* _data11_);
static void ___lambda60__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda61_ (Block11Data* _data11_);
static void ___lambda61__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
void boxes_actor_remove (ClutterActor* actor);
GList* boxes_collection_view_get_selected_items (BoxesCollectionView* self);
static Block12Data* block12_data_ref (Block12Data* _data12_);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static void block12_data_unref (void * _userdata_);
static gboolean __lambda62_ (Block12Data* _data12_, GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter);
static gboolean ___lambda62__gtk_tree_model_foreach_func (GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter, gpointer self);
void boxes_collection_view_remove_item (BoxesCollectionView* self, BoxesCollectionItem* item);
static BoxesCollectionItem* boxes_collection_view_get_item_for_iter (BoxesCollectionView* self, GtkTreeIter* iter);
static BoxesCollectionItem* boxes_collection_view_get_item_for_path (BoxesCollectionView* self, GtkTreePath* path);
static gboolean boxes_collection_view_model_visible (BoxesCollectionView* self, GtkTreeModel* model, GtkTreeIter* iter);
GType boxes_clutter_widget_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
gboolean boxes_collection_filter_filter (BoxesCollectionFilter* self, BoxesCollectionItem* item);
void boxes_collection_view_refilter (BoxesCollectionView* self);
void boxes_collection_view_activate (BoxesCollectionView* self);
static gint __lambda34_ (BoxesCollectionView* self, GtkTreeModel* model, GtkTreeIter* a, GtkTreeIter* b);
gint boxes_collection_item_compare (BoxesCollectionItem* self, BoxesCollectionItem* other);
static gint ___lambda34__gtk_tree_iter_compare_func (GtkTreeModel* model, GtkTreeIter* a, GtkTreeIter* b, gpointer self);
static void __lambda35_ (BoxesCollectionView* self);
static void ___lambda35__gtk_tree_model_row_deleted (GtkTreeModel* _sender, GtkTreePath* path, gpointer self);
static void __lambda36_ (BoxesCollectionView* self);
static void ___lambda36__gtk_tree_model_row_inserted (GtkTreeModel* _sender, GtkTreePath* path, GtkTreeIter* iter, gpointer self);
static gboolean _boxes_collection_view_model_visible_gtk_tree_model_filter_visible_func (GtkTreeModel* model, GtkTreeIter* iter, gpointer self);
static void __lambda37_ (BoxesCollectionView* self, GdMainView* view, const gchar* id, GtkTreePath* path);
void boxes_app_select_item (BoxesApp* self, BoxesCollectionItem* item);
static void ___lambda37__gd_main_view_item_activated (GdMainView* _sender, const gchar* object, GtkTreePath* p0, gpointer self);
static void __lambda54_ (BoxesCollectionView* self);
static void ___lambda54__gd_main_view_view_selection_changed (GdMainView* _sender, gpointer self);
static void __lambda55_ (BoxesCollectionView* self);
void boxes_app_set_selection_mode (BoxesApp* self, gboolean value);
static void ___lambda55__gd_main_view_selection_mode_request (GdMainView* _sender, gpointer self);
void boxes_collection_view_select (BoxesCollectionView* self, BoxesSelectionCriteria selection);
static Block13Data* block13_data_ref (Block13Data* _data13_);
static void block13_data_unref (void * _userdata_);
static gboolean __lambda63_ (Block13Data* _data13_, GtkTreeModel* filter_model, GtkTreePath* filter_path, GtkTreeIter* filter_iter);
gboolean boxes_machine_is_running (BoxesMachine* self);
static gboolean ___lambda63__gtk_tree_model_foreach_func (GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter, gpointer self);
void boxes_collection_view_set_visible (BoxesCollectionView* self, gboolean value);
static void boxes_collection_view_finalize (GObject* obj);
static void _vala_boxes_collection_view_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_collection_view_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


GType boxes_selection_criteria_get_type (void) {
	static volatile gsize boxes_selection_criteria_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_selection_criteria_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_SELECTION_CRITERIA_ALL, "BOXES_SELECTION_CRITERIA_ALL", "all"}, {BOXES_SELECTION_CRITERIA_NONE, "BOXES_SELECTION_CRITERIA_NONE", "none"}, {BOXES_SELECTION_CRITERIA_RUNNING, "BOXES_SELECTION_CRITERIA_RUNNING", "running"}, {0, NULL, NULL}};
		GType boxes_selection_criteria_type_id;
		boxes_selection_criteria_type_id = g_enum_register_static ("BoxesSelectionCriteria", values);
		g_once_init_leave (&boxes_selection_criteria_type_id__volatile, boxes_selection_criteria_type_id);
	}
	return boxes_selection_criteria_type_id__volatile;
}


static GType boxes_collection_view_model_columns_get_type (void) {
	static volatile gsize boxes_collection_view_model_columns_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_collection_view_model_columns_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SCREENSHOT, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SCREENSHOT", "screenshot"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_TITLE, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_TITLE", "title"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_INFO, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_INFO", "info"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED", "selected"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM", "item"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_LAST, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_LAST", "last"}, {0, NULL, NULL}};
		GType boxes_collection_view_model_columns_type_id;
		boxes_collection_view_model_columns_type_id = g_enum_register_static ("BoxesCollectionViewModelColumns", values);
		g_once_init_leave (&boxes_collection_view_model_columns_type_id__volatile, boxes_collection_view_model_columns_type_id);
	}
	return boxes_collection_view_model_columns_type_id__volatile;
}


static void __lambda56_ (BoxesCollectionView* self) {
	GdMainView* _tmp0_;
	BoxesApp* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	BoxesApp* _tmp4_;
	gboolean _tmp5_;
	gboolean _tmp6_;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->main_view;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_app_app;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = boxes_app_get_selection_mode (_tmp1_);
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = _tmp2_;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gd_main_view_set_selection_mode (_tmp0_, _tmp3_);
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = boxes_app_app;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = boxes_app_get_selection_mode (_tmp4_);
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = _tmp5_;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (!_tmp6_) {
#line 616 "collection-view.c"
		GdMainView* _tmp7_;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp7_ = self->main_view;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		gd_main_view_unselect_all (_tmp7_);
#line 622 "collection-view.c"
	}
}


static void ___lambda56__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda56_ (self);
#line 630 "collection-view.c"
}


BoxesCollectionView* boxes_collection_view_construct (GType object_type) {
	BoxesCollectionView * self = NULL;
	const gchar* _tmp0_ = NULL;
	BoxesCategory* _tmp1_;
	BoxesCategory* _tmp2_;
	BoxesApp* _tmp3_;
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = (BoxesCollectionView*) boxes_ui_construct (object_type);
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = _ ("New and Recent");
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_category_new (_tmp0_, BOXES_CATEGORY_KIND_NEW);
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _tmp1_;
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_set_category (self, _tmp2_);
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (_tmp2_);
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_setup_view (self);
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = boxes_app_app;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GObject*) _tmp3_, "notify::selection-mode", (GCallback) ___lambda56__g_object_notify, self, 0);
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return self;
#line 660 "collection-view.c"
}


BoxesCollectionView* boxes_collection_view_new (void) {
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return boxes_collection_view_construct (BOXES_TYPE_COLLECTION_VIEW);
#line 667 "collection-view.c"
}


void boxes_collection_view_get_item_pos (BoxesCollectionView* self, BoxesCollectionItem* item, gfloat* x, gfloat* y) {
	gfloat _vala_x = 0.0F;
	gfloat _vala_y = 0.0F;
	GdkRectangle rect = {0};
	GtkTreePath* path = NULL;
	BoxesCollectionItem* _tmp0_;
	GtkTreePath* _tmp1_ = NULL;
	GtkTreePath* _tmp2_;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (item != NULL);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = item;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_collection_view_get_path_for_item (self, _tmp0_);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	path = _tmp1_;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = path;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp2_ != NULL) {
#line 693 "collection-view.c"
		GdMainView* _tmp3_;
		GtkWidget* _tmp4_ = NULL;
		GtkTreePath* _tmp5_;
		GdkRectangle _tmp6_ = {0};
		GdkRectangle _tmp7_;
		gint _tmp8_;
		GdkRectangle _tmp9_;
		gint _tmp10_;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp3_ = self->main_view;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp4_ = gd_main_view_get_generic_view (_tmp3_);
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp5_ = path;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		gtk_icon_view_get_cell_rect (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GTK_TYPE_ICON_VIEW) ? ((GtkIconView*) _tmp4_) : NULL, _tmp5_, NULL, &_tmp6_);
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		rect = _tmp6_;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp7_ = rect;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp8_ = _tmp7_.x;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_vala_x = (gfloat) _tmp8_;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp9_ = rect;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp10_ = _tmp9_.y;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_vala_y = (gfloat) _tmp10_;
#line 724 "collection-view.c"
	} else {
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_vala_x = 0.0f;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_vala_y = 0.0f;
#line 730 "collection-view.c"
	}
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_gtk_tree_path_free0 (path);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (x) {
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		*x = _vala_x;
#line 738 "collection-view.c"
	}
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (y) {
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		*y = _vala_y;
#line 744 "collection-view.c"
	}
}


static void boxes_collection_view_real_ui_state_changed (BoxesUI* base) {
	BoxesCollectionView * self;
	BoxesUIState _tmp0_;
	BoxesUIState _tmp1_;
	gint _tmp3_ = 0;
	BoxesUIState _tmp4_;
	BoxesUIState _tmp5_;
	ClutterActor* _tmp6_;
	ClutterActor* _tmp7_;
	gint _tmp8_;
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = (BoxesCollectionView*) base;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _tmp0_;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp1_ == BOXES_UI_STATE_COLLECTION) {
#line 767 "collection-view.c"
		GdMainView* _tmp2_;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp2_ = self->main_view;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		gd_main_view_unselect_all (_tmp2_);
#line 773 "collection-view.c"
	}
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = _tmp4_;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp5_ == BOXES_UI_STATE_COLLECTION) {
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp3_ = 255;
#line 783 "collection-view.c"
	} else {
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp3_ = 0;
#line 787 "collection-view.c"
	}
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = boxes_ui_get_actor ((BoxesUI*) self);
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = _tmp6_;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = _tmp3_;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_fade_actor (_tmp7_, (guint) _tmp8_);
#line 797 "collection-view.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return self ? g_object_ref (self) : NULL;
#line 804 "collection-view.c"
}


static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle) {
	int i;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	for (i = 0; i < stack_length; i++) {
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			return TRUE;
#line 816 "collection-view.c"
		}
	}
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return FALSE;
#line 821 "collection-view.c"
}


static void boxes_collection_view_update_item_visible (BoxesCollectionView* self, BoxesCollectionItem* item) {
	gboolean visible = FALSE;
	BoxesCollectionItem* _tmp0_;
	BoxesCollectionItem* _tmp14_;
	ClutterActor* _tmp15_;
	ClutterActor* _tmp16_;
	gboolean _tmp17_;
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (item != NULL);
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	visible = FALSE;
#line 75 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = item;
#line 75 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, BOXES_TYPE_MACHINE)) {
#line 842 "collection-view.c"
		BoxesMachine* machine = NULL;
		BoxesCollectionItem* _tmp1_;
		BoxesMachine* _tmp2_;
		BoxesCategory* _tmp3_;
		BoxesCategory* _tmp4_;
		BoxesCategoryKind _tmp5_;
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp1_ = item;
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp1_) : NULL);
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		machine = _tmp2_;
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp3_ = boxes_collection_view_get_category (self);
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp4_ = _tmp3_;
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp5_ = _tmp4_->kind;
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		switch (_tmp5_) {
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			case BOXES_CATEGORY_KIND_USER:
#line 865 "collection-view.c"
			{
				BoxesCategory* _tmp6_;
				BoxesCategory* _tmp7_;
				const gchar* _tmp8_;
				BoxesMachine* _tmp9_;
				BoxesBoxConfig* _tmp10_;
				gchar** _tmp11_;
				gint _tmp11__length1;
				gchar** _tmp12_;
				gint _tmp12__length1;
				gchar** _tmp13_;
				gint _tmp13__length1;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp6_ = boxes_collection_view_get_category (self);
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp7_ = _tmp6_;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp8_ = _tmp7_->name;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp9_ = machine;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp10_ = _tmp9_->config;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp11_ = boxes_box_config_get_categories (_tmp10_, &_tmp11__length1);
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp12_ = _tmp11_;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp12__length1 = _tmp11__length1;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp13_ = _tmp12_;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp13__length1 = _tmp12__length1;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				visible = _vala_string_array_contains (_tmp13_, _tmp12__length1, _tmp8_);
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp13_ = (_vala_array_free (_tmp13_, _tmp13__length1, (GDestroyNotify) g_free), NULL);
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				break;
#line 904 "collection-view.c"
			}
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			case BOXES_CATEGORY_KIND_NEW:
#line 908 "collection-view.c"
			{
#line 83 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				visible = TRUE;
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				break;
#line 914 "collection-view.c"
			}
			default:
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			break;
#line 919 "collection-view.c"
		}
#line 75 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (machine);
#line 923 "collection-view.c"
	}
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14_ = item;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp15_ = boxes_ui_get_actor ((BoxesUI*) _tmp14_);
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp16_ = _tmp15_;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp17_ = visible;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set (_tmp16_, "visible", _tmp17_, NULL);
#line 935 "collection-view.c"
}


static void _vala_array_add1 (GIcon*** array, int* length, int* size, GIcon* value) {
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if ((*length) == (*size)) {
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		*array = g_renew (GIcon*, *array, (*size) + 1);
#line 946 "collection-view.c"
	}
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	(*array)[(*length)++] = value;
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	(*array)[*length] = NULL;
#line 952 "collection-view.c"
}


static void boxes_collection_view_update_screenshot (BoxesCollectionView* self, GtkTreeIter* iter) {
	BoxesCollectionItem* item = NULL;
	GIcon** emblem_icons = NULL;
	GIcon** _tmp0_ = NULL;
	gint emblem_icons_length1;
	gint _emblem_icons_size_;
	GtkListStore* _tmp1_;
	GtkTreeIter _tmp2_;
	BoxesMachine* machine = NULL;
	BoxesCollectionItem* _tmp3_;
	BoxesMachine* _tmp4_;
	BoxesMachine* _tmp5_;
	GdkPixbuf* pixbuf = NULL;
	BoxesMachine* _tmp6_;
	GdkPixbuf* _tmp7_;
	GdkPixbuf* _tmp8_;
	GdkPixbuf* _tmp9_;
	BoxesMachine* _tmp10_;
	BoxesBoxConfig* _tmp11_;
	gchar** _tmp12_;
	gint _tmp12__length1;
	gchar** _tmp13_;
	gint _tmp13__length1;
	gchar** _tmp14_;
	gint _tmp14__length1;
	gboolean _tmp15_;
	GIcon** _tmp18_;
	gint _tmp18__length1;
	GtkListStore* _tmp47_;
	GtkTreeIter _tmp48_;
	GdkPixbuf* _tmp49_;
	GdMainView* _tmp50_;
	GError * _inner_error_ = NULL;
#line 91 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 91 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (iter != NULL);
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = g_new0 (GIcon*, 0 + 1);
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	emblem_icons = _tmp0_;
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	emblem_icons_length1 = 0;
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_emblem_icons_size_ = emblem_icons_length1;
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = self->priv->model;
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = *iter;
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get ((GtkTreeModel*) _tmp1_, &_tmp2_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &item, -1);
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = item;
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp3_) : NULL);
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	machine = _tmp4_;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = machine;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (_tmp5_ != NULL);
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = machine;
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = boxes_machine_get_pixbuf (_tmp6_);
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = _tmp7_;
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = _g_object_ref0 (_tmp8_);
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	pixbuf = _tmp9_;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = machine;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp11_ = _tmp10_->config;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp12_ = boxes_box_config_get_categories (_tmp11_, &_tmp12__length1);
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp13_ = _tmp12_;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp13__length1 = _tmp12__length1;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14_ = _tmp13_;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14__length1 = _tmp13__length1;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp15_ = _vala_string_array_contains (_tmp14_, _tmp13__length1, "favorite");
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14_ = (_vala_array_free (_tmp14_, _tmp14__length1, (GDestroyNotify) g_free), NULL);
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp15_) {
#line 1047 "collection-view.c"
		GIcon** _tmp16_;
		gint _tmp16__length1;
		GIcon* _tmp17_ = NULL;
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp16_ = emblem_icons;
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp16__length1 = emblem_icons_length1;
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp17_ = boxes_create_symbolic_emblem ("emblem-favorite");
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_vala_array_add1 (&emblem_icons, &emblem_icons_length1, &_emblem_icons_size_, _tmp17_);
#line 1059 "collection-view.c"
	}
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp18_ = emblem_icons;
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp18__length1 = emblem_icons_length1;
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp18__length1 > 0) {
#line 1067 "collection-view.c"
		GEmblemedIcon* emblemed_icon = NULL;
		GdkPixbuf* _tmp19_;
		GEmblemedIcon* _tmp20_;
		GIcon** _tmp21_;
		gint _tmp21__length1;
		GtkIconTheme* theme = NULL;
		GtkIconTheme* _tmp27_ = NULL;
		GtkIconTheme* _tmp28_;
#line 104 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp19_ = pixbuf;
#line 104 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp20_ = (GEmblemedIcon*) g_emblemed_icon_new ((GIcon*) _tmp19_, NULL);
#line 104 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		emblemed_icon = _tmp20_;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp21_ = emblem_icons;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp21__length1 = emblem_icons_length1;
#line 1086 "collection-view.c"
		{
			GIcon** emblem_icon_collection = NULL;
			gint emblem_icon_collection_length1 = 0;
			gint _emblem_icon_collection_size_ = 0;
			gint emblem_icon_it = 0;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			emblem_icon_collection = _tmp21_;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			emblem_icon_collection_length1 = _tmp21__length1;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			for (emblem_icon_it = 0; emblem_icon_it < _tmp21__length1; emblem_icon_it = emblem_icon_it + 1) {
#line 1098 "collection-view.c"
				GIcon* _tmp22_;
				GIcon* emblem_icon = NULL;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp22_ = _g_object_ref0 (emblem_icon_collection[emblem_icon_it]);
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				emblem_icon = _tmp22_;
#line 1105 "collection-view.c"
				{
					GEmblemedIcon* _tmp23_;
					GIcon* _tmp24_;
					GEmblem* _tmp25_;
					GEmblem* _tmp26_;
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
					_tmp23_ = emblemed_icon;
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
					_tmp24_ = emblem_icon;
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
					_tmp25_ = g_emblem_new (_tmp24_);
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
					_tmp26_ = _tmp25_;
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
					g_emblemed_icon_add_emblem (_tmp23_, _tmp26_);
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
					_g_object_unref0 (_tmp26_);
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
					_g_object_unref0 (emblem_icon);
#line 1125 "collection-view.c"
				}
			}
		}
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp27_ = gtk_icon_theme_get_default ();
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp28_ = _g_object_ref0 (_tmp27_);
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		theme = _tmp28_;
#line 1135 "collection-view.c"
		{
			gint size = 0;
			GdkPixbuf* _tmp29_;
			gint _tmp30_;
			gint _tmp31_;
			GdkPixbuf* _tmp32_;
			gint _tmp33_;
			gint _tmp34_;
			gint _tmp35_ = 0;
			GtkIconInfo* icon_info = NULL;
			GtkIconTheme* _tmp36_;
			GEmblemedIcon* _tmp37_;
			gint _tmp38_;
			GtkIconInfo* _tmp39_ = NULL;
			GdkPixbuf* _tmp40_ = NULL;
			GtkIconInfo* _tmp41_;
			GdkPixbuf* _tmp42_ = NULL;
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp29_ = pixbuf;
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp30_ = gdk_pixbuf_get_width (_tmp29_);
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp31_ = _tmp30_;
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp32_ = pixbuf;
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp33_ = gdk_pixbuf_get_height (_tmp32_);
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp34_ = _tmp33_;
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp35_ = MAX (_tmp31_, _tmp34_);
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			size = _tmp35_;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp36_ = theme;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp37_ = emblemed_icon;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp38_ = size;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp39_ = gtk_icon_theme_lookup_by_gicon (_tmp36_, (GIcon*) _tmp37_, _tmp38_, GTK_ICON_LOOKUP_FORCE_SIZE);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			icon_info = _tmp39_;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp41_ = icon_info;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp42_ = gtk_icon_info_load_icon (_tmp41_, &_inner_error_);
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp40_ = _tmp42_;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			if (_inner_error_ != NULL) {
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_gtk_icon_info_free0 (icon_info);
#line 1189 "collection-view.c"
				goto __catch7_g_error;
			}
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (pixbuf);
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			pixbuf = _tmp40_;
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_gtk_icon_info_free0 (icon_info);
#line 1198 "collection-view.c"
		}
		goto __finally7;
		__catch7_g_error:
		{
			GError* _error_ = NULL;
			GError* _tmp43_;
			const gchar* _tmp44_;
			gchar* _tmp45_;
			gchar* _tmp46_;
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_error_ = _inner_error_;
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_inner_error_ = NULL;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp43_ = _error_;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp44_ = _tmp43_->message;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp45_ = g_strconcat ("Unable to render the emblem: ", _tmp44_, NULL);
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp46_ = _tmp45_;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			g_warning ("collection-view.vala:116: %s", _tmp46_);
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_free0 (_tmp46_);
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_error_free0 (_error_);
#line 1226 "collection-view.c"
		}
		__finally7:
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		if (_inner_error_ != NULL) {
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (theme);
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (emblemed_icon);
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (pixbuf);
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (machine);
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			emblem_icons = (_vala_array_free (emblem_icons, emblem_icons_length1, (GDestroyNotify) g_object_unref), NULL);
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (item);
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			g_clear_error (&_inner_error_);
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			return;
#line 1249 "collection-view.c"
		}
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (theme);
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (emblemed_icon);
#line 1255 "collection-view.c"
	}
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp47_ = self->priv->model;
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp48_ = *iter;
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp49_ = pixbuf;
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp47_, &_tmp48_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SCREENSHOT, _tmp49_, -1);
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp50_ = self->main_view;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) _tmp50_);
#line 91 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (pixbuf);
#line 91 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (machine);
#line 91 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	emblem_icons = (_vala_array_free (emblem_icons, emblem_icons_length1, (GDestroyNotify) g_object_unref), NULL);
#line 91 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item);
#line 1277 "collection-view.c"
}


static GtkTreeIter* _gtk_tree_iter_dup (GtkTreeIter* self) {
	GtkTreeIter* dup;
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	dup = g_new0 (GtkTreeIter, 1);
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	memcpy (dup, self, sizeof (GtkTreeIter));
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return dup;
#line 1289 "collection-view.c"
}


static gpointer __gtk_tree_iter_dup0 (gpointer self) {
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return self ? _gtk_tree_iter_dup (self) : NULL;
#line 1296 "collection-view.c"
}


static void boxes_collection_view_append (BoxesCollectionView* self, const gchar* title, const gchar* info, BoxesCollectionItem* item, GtkTreeIter* result) {
	GtkTreeIter iter = {0};
	GtkListStore* _tmp0_;
	GtkTreeIter _tmp1_ = {0};
	GtkListStore* _tmp2_;
	GtkTreeIter _tmp3_;
	BoxesCollectionItem* _tmp4_;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_;
	GtkListStore* _tmp7_;
	GtkTreeIter _tmp8_;
	const gchar* _tmp9_;
	const gchar* _tmp10_;
	GtkListStore* _tmp14_;
	GtkTreeIter _tmp15_;
	GtkListStore* _tmp16_;
	GtkTreeIter _tmp17_;
	BoxesCollectionItem* _tmp18_;
	GtkTreeIter _tmp19_;
	BoxesCollectionItem* _tmp20_;
	GtkTreeIter _tmp21_;
	GtkTreeIter* _tmp22_;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (title != NULL);
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (item != NULL);
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_append (_tmp0_, &_tmp1_);
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iter = _tmp1_;
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = self->priv->model;
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = iter;
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = item;
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = g_strdup_printf ("%p", _tmp4_);
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = _tmp5_;
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp2_, &_tmp3_, GD_MAIN_COLUMN_ID, _tmp6_, -1);
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_free0 (_tmp6_);
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = self->priv->model;
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = iter;
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = title;
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp7_, &_tmp8_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_TITLE, _tmp9_, -1);
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = info;
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp10_ != NULL) {
#line 1360 "collection-view.c"
		GtkListStore* _tmp11_;
		GtkTreeIter _tmp12_;
		const gchar* _tmp13_;
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp11_ = self->priv->model;
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp12_ = iter;
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp13_ = info;
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		gtk_list_store_set (_tmp11_, &_tmp12_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_INFO, _tmp13_, -1);
#line 1372 "collection-view.c"
	}
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14_ = self->priv->model;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp15_ = iter;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp14_, &_tmp15_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED, FALSE, -1);
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp16_ = self->priv->model;
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp17_ = iter;
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp18_ = item;
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp16_, &_tmp17_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, _tmp18_, -1);
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp19_ = iter;
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_update_screenshot (self, &_tmp19_);
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp20_ = item;
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp21_ = iter;
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp22_ = __gtk_tree_iter_dup0 (&_tmp21_);
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp20_, "iter", _tmp22_, g_free);
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	*result = iter;
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return;
#line 1404 "collection-view.c"
}


static Block11Data* block11_data_ref (Block11Data* _data11_) {
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_atomic_int_inc (&_data11_->_ref_count_);
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return _data11_;
#line 1413 "collection-view.c"
}


static void block11_data_unref (void * _userdata_) {
	Block11Data* _data11_;
	_data11_ = (Block11Data*) _userdata_;
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (g_atomic_int_dec_and_test (&_data11_->_ref_count_)) {
#line 1422 "collection-view.c"
		BoxesCollectionView * self;
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		self = _data11_->self;
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (_data11_->machine);
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (_data11_->item);
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (self);
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_slice_free (Block11Data, _data11_);
#line 1434 "collection-view.c"
	}
}


static void __lambda58_ (Block11Data* _data11_) {
	BoxesCollectionView * self;
	GtkTreeIter _tmp0_;
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data11_->self;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = _data11_->iter;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_update_screenshot (self, &_tmp0_);
#line 1448 "collection-view.c"
}


static void ___lambda58__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda58_ (self);
#line 1455 "collection-view.c"
}


static void __lambda59_ (Block11Data* _data11_) {
	BoxesCollectionView * self;
	GtkTreeIter _tmp0_;
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data11_->self;
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = _data11_->iter;
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_update_screenshot (self, &_tmp0_);
#line 1468 "collection-view.c"
}


static void ___lambda59__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda59_ (self);
#line 1475 "collection-view.c"
}


static void __lambda60_ (Block11Data* _data11_) {
	BoxesCollectionView * self;
	GtkListStore* _tmp0_;
	GtkTreeIter _tmp1_;
	BoxesCollectionItem* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	GdMainView* _tmp5_;
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data11_->self;
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model;
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _data11_->iter;
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _data11_->item;
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = boxes_collection_item_get_name (_tmp2_);
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _tmp3_;
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp0_, &_tmp1_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_TITLE, _tmp4_, -1);
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = self->main_view;
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) _tmp5_);
#line 1505 "collection-view.c"
}


static void ___lambda60__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda60_ (self);
#line 1512 "collection-view.c"
}


static void __lambda61_ (Block11Data* _data11_) {
	BoxesCollectionView * self;
	GtkListStore* _tmp0_;
	GtkTreeIter _tmp1_;
	BoxesMachine* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	GdMainView* _tmp5_;
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data11_->self;
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model;
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _data11_->iter;
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _data11_->machine;
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = boxes_machine_get_info (_tmp2_);
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _tmp3_;
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp0_, &_tmp1_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_INFO, _tmp4_, -1);
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = self->main_view;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) _tmp5_);
#line 1542 "collection-view.c"
}


static void ___lambda61__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda61_ (self);
#line 1549 "collection-view.c"
}


void boxes_collection_view_add_item (BoxesCollectionView* self, BoxesCollectionItem* item) {
	Block11Data* _data11_;
	BoxesCollectionItem* _tmp0_;
	BoxesCollectionItem* _tmp1_;
	BoxesCollectionItem* _tmp2_;
	BoxesMachine* _tmp3_;
	BoxesMachine* _tmp4_;
	BoxesMachine* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	BoxesMachine* _tmp10_;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
	BoxesCollectionItem* _tmp13_;
	GtkTreeIter _tmp14_ = {0};
	gulong pixbuf_id = 0UL;
	BoxesMachine* _tmp15_;
	gulong _tmp16_ = 0UL;
	BoxesCollectionItem* _tmp17_;
	gulong _tmp18_;
	gulong categories_id = 0UL;
	BoxesMachine* _tmp19_;
	BoxesBoxConfig* _tmp20_;
	gulong _tmp21_ = 0UL;
	BoxesCollectionItem* _tmp22_;
	gulong _tmp23_;
	gulong name_id = 0UL;
	BoxesCollectionItem* _tmp24_;
	gulong _tmp25_ = 0UL;
	BoxesCollectionItem* _tmp26_;
	gulong _tmp27_;
	gulong info_id = 0UL;
	BoxesMachine* _tmp28_;
	gulong _tmp29_ = 0UL;
	BoxesCollectionItem* _tmp30_;
	gulong _tmp31_;
	BoxesCollectionItem* _tmp32_;
	BoxesApp* _tmp33_;
	BoxesUIState _tmp34_;
	BoxesUIState _tmp35_;
	BoxesCollectionItem* _tmp36_;
	ClutterActor* _tmp37_;
	ClutterActor* _tmp38_;
	BoxesCollectionItem* _tmp39_;
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (item != NULL);
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data11_ = g_slice_new0 (Block11Data);
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data11_->_ref_count_ = 1;
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data11_->self = g_object_ref (self);
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = item;
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (_data11_->item);
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data11_->item = _tmp1_;
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _data11_->item;
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp2_) : NULL);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data11_->machine = _tmp3_;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _data11_->machine;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp4_ == NULL) {
#line 1625 "collection-view.c"
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_;
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp5_ = g_strdup_printf ("Cannot add item %p", &_data11_->item);
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp6_ = _tmp5_;
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_warning ("collection-view.vala:147: %s", _tmp6_);
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_free0 (_tmp6_);
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		block11_data_unref (_data11_);
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_data11_ = NULL;
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return;
#line 1642 "collection-view.c"
	}
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = _data11_->machine;
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp7_);
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = _tmp8_;
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = _data11_->machine;
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp11_ = boxes_machine_get_info (_tmp10_);
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp12_ = _tmp11_;
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp13_ = _data11_->item;
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_append (self, _tmp9_, _tmp12_, _tmp13_, &_tmp14_);
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data11_->iter = _tmp14_;
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp15_ = _data11_->machine;
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp16_ = g_signal_connect_data ((GObject*) _tmp15_, "notify::pixbuf", (GCallback) ___lambda58__g_object_notify, block11_data_ref (_data11_), (GClosureNotify) block11_data_unref, 0);
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	pixbuf_id = _tmp16_;
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp17_ = _data11_->item;
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp18_ = pixbuf_id;
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp17_, "pixbuf_id", (gpointer) ((guintptr) _tmp18_), NULL);
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp19_ = _data11_->machine;
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp20_ = _tmp19_->config;
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp21_ = g_signal_connect_data ((GObject*) _tmp20_, "notify::categories", (GCallback) ___lambda59__g_object_notify, block11_data_ref (_data11_), (GClosureNotify) block11_data_unref, 0);
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	categories_id = _tmp21_;
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp22_ = _data11_->item;
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp23_ = categories_id;
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp22_, "categories_id", (gpointer) ((guintptr) _tmp23_), NULL);
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp24_ = _data11_->item;
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp25_ = g_signal_connect_data ((GObject*) _tmp24_, "notify::name", (GCallback) ___lambda60__g_object_notify, block11_data_ref (_data11_), (GClosureNotify) block11_data_unref, 0);
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	name_id = _tmp25_;
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp26_ = _data11_->item;
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp27_ = name_id;
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp26_, "name_id", (gpointer) ((guintptr) _tmp27_), NULL);
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp28_ = _data11_->machine;
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp29_ = g_signal_connect_data ((GObject*) _tmp28_, "notify::info", (GCallback) ___lambda61__g_object_notify, block11_data_ref (_data11_), (GClosureNotify) block11_data_unref, 0);
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	info_id = _tmp29_;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp30_ = _data11_->item;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp31_ = info_id;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp30_, "info_id", (gpointer) ((guintptr) _tmp31_), NULL);
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp32_ = _data11_->item;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp33_ = boxes_app_app;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp34_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp33_);
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp35_ = _tmp34_;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_ui_set_ui_state ((BoxesUI*) _tmp32_, _tmp35_);
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp36_ = _data11_->item;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp37_ = boxes_ui_get_actor ((BoxesUI*) _tmp36_);
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp38_ = _tmp37_;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_actor_remove (_tmp38_);
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp39_ = _data11_->item;
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_update_item_visible (self, _tmp39_);
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	block11_data_unref (_data11_);
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data11_ = NULL;
#line 1738 "collection-view.c"
}


static Block12Data* block12_data_ref (Block12Data* _data12_) {
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_atomic_int_inc (&_data12_->_ref_count_);
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return _data12_;
#line 1747 "collection-view.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1754 "collection-view.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_list_free (self);
#line 1763 "collection-view.c"
}


static void block12_data_unref (void * _userdata_) {
	Block12Data* _data12_;
	_data12_ = (Block12Data*) _userdata_;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (g_atomic_int_dec_and_test (&_data12_->_ref_count_)) {
#line 1772 "collection-view.c"
		BoxesCollectionView * self;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		self = _data12_->self;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		__g_list_free__g_object_unref0_0 (_data12_->selected);
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (self);
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_slice_free (Block12Data, _data12_);
#line 1782 "collection-view.c"
	}
}


static gboolean __lambda62_ (Block12Data* _data12_, GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter) {
	BoxesCollectionView * self;
	gboolean result = FALSE;
	BoxesCollectionItem* item = NULL;
	gboolean is_selected = FALSE;
	GtkTreeModel* _tmp0_;
	GtkTreeIter _tmp1_;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_;
	gboolean _tmp5_;
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data12_->self;
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (model != NULL, FALSE);
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (iter != NULL, FALSE);
#line 191 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = model;
#line 191 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = *iter;
#line 191 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get (_tmp0_, &_tmp1_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED, &is_selected, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &item, -1);
#line 194 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = is_selected;
#line 194 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp3_) {
#line 1815 "collection-view.c"
		BoxesCollectionItem* _tmp4_;
#line 194 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp4_ = item;
#line 194 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp2_ = _tmp4_ != NULL;
#line 1821 "collection-view.c"
	} else {
#line 194 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp2_ = FALSE;
#line 1825 "collection-view.c"
	}
#line 194 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = _tmp2_;
#line 194 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp5_) {
#line 1831 "collection-view.c"
		BoxesCollectionItem* _tmp6_;
		BoxesCollectionItem* _tmp7_;
#line 195 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp6_ = item;
#line 195 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp7_ = _g_object_ref0 (_tmp6_);
#line 195 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_data12_->selected = g_list_append (_data12_->selected, _tmp7_);
#line 1840 "collection-view.c"
	}
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = FALSE;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item);
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 1848 "collection-view.c"
}


static gboolean ___lambda62__gtk_tree_model_foreach_func (GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter, gpointer self) {
	gboolean result;
	result = __lambda62_ (self, model, path, iter);
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 1857 "collection-view.c"
}


GList* boxes_collection_view_get_selected_items (BoxesCollectionView* self) {
	GList* result = NULL;
	Block12Data* _data12_;
	GtkListStore* _tmp0_;
	GList* _tmp1_;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data12_ = g_slice_new0 (Block12Data);
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data12_->_ref_count_ = 1;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data12_->self = g_object_ref (self);
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data12_->selected = NULL;
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model;
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_foreach ((GtkTreeModel*) _tmp0_, ___lambda62__gtk_tree_model_foreach_func, _data12_);
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _data12_->selected;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data12_->selected = NULL;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp1_;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	block12_data_unref (_data12_);
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data12_ = NULL;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 1892 "collection-view.c"
}


void boxes_collection_view_remove_item (BoxesCollectionView* self, BoxesCollectionItem* item) {
	GtkTreeIter* iter = NULL;
	BoxesCollectionItem* _tmp0_;
	gconstpointer _tmp1_ = NULL;
	GtkTreeIter* _tmp2_;
	GtkTreeIter* _tmp3_;
	GtkListStore* _tmp4_;
	GtkTreeIter* _tmp5_;
	GtkTreeIter _tmp6_;
	BoxesCollectionItem* _tmp7_;
	gulong pixbuf_id = 0UL;
	BoxesCollectionItem* _tmp8_;
	gconstpointer _tmp9_ = NULL;
	BoxesCollectionItem* _tmp10_;
	gulong _tmp11_;
	gulong name_id = 0UL;
	BoxesCollectionItem* _tmp12_;
	gconstpointer _tmp13_ = NULL;
	BoxesCollectionItem* _tmp14_;
	gulong _tmp15_;
	gulong info_id = 0UL;
	BoxesCollectionItem* _tmp16_;
	gconstpointer _tmp17_ = NULL;
	BoxesCollectionItem* _tmp18_;
	gulong _tmp19_;
	BoxesCollectionItem* _tmp20_;
#line 203 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 203 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (item != NULL);
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = item;
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = g_object_get_data ((GObject*) _tmp0_, "iter");
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = __gtk_tree_iter_dup0 ((GtkTreeIter*) _tmp1_);
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iter = _tmp2_;
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = iter;
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp3_ == NULL) {
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_debug ("collection-view.vala:206: item not in view or already removed");
#line 207 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_free0 (iter);
#line 207 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return;
#line 1944 "collection-view.c"
	}
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = self->priv->model;
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = iter;
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = *_tmp5_;
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_remove (_tmp4_, &_tmp6_);
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = item;
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp7_, "iter", NULL, g_free);
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = item;
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = g_object_get_data ((GObject*) _tmp8_, "pixbuf_id");
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	pixbuf_id = (gulong) ((guintptr) _tmp9_);
#line 214 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = item;
#line 214 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp11_ = pixbuf_id;
#line 214 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_handler_disconnect ((GObject*) _tmp10_, _tmp11_);
#line 215 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp12_ = item;
#line 215 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp13_ = g_object_get_data ((GObject*) _tmp12_, "name_id");
#line 215 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	name_id = (gulong) ((guintptr) _tmp13_);
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14_ = item;
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp15_ = name_id;
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_handler_disconnect ((GObject*) _tmp14_, _tmp15_);
#line 217 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp16_ = item;
#line 217 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp17_ = g_object_get_data ((GObject*) _tmp16_, "info_id");
#line 217 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	info_id = (gulong) ((guintptr) _tmp17_);
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp18_ = item;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp19_ = info_id;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_handler_disconnect ((GObject*) _tmp18_, _tmp19_);
#line 220 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp20_ = item;
#line 220 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if ((G_TYPE_CHECK_INSTANCE_TYPE (_tmp20_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp20_) : NULL) != NULL) {
#line 1998 "collection-view.c"
		BoxesMachine* machine = NULL;
		BoxesCollectionItem* _tmp21_;
		BoxesMachine* _tmp22_;
		gulong categories_id = 0UL;
		BoxesCollectionItem* _tmp23_;
		gconstpointer _tmp24_ = NULL;
		BoxesMachine* _tmp25_;
		BoxesBoxConfig* _tmp26_;
		gulong _tmp27_;
#line 221 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp21_ = item;
#line 221 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp22_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp21_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp21_) : NULL);
#line 221 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		machine = _tmp22_;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp23_ = item;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp24_ = g_object_get_data ((GObject*) _tmp23_, "categories_id");
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		categories_id = (gulong) ((guintptr) _tmp24_);
#line 223 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp25_ = machine;
#line 223 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp26_ = _tmp25_->config;
#line 223 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp27_ = categories_id;
#line 223 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_signal_handler_disconnect ((GObject*) _tmp26_, _tmp27_);
#line 220 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (machine);
#line 2030 "collection-view.c"
	}
#line 203 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_free0 (iter);
#line 2034 "collection-view.c"
}


static GtkTreePath* boxes_collection_view_get_path_for_item (BoxesCollectionView* self, BoxesCollectionItem* item) {
	GtkTreePath* result = NULL;
	GtkTreeIter* iter = NULL;
	BoxesCollectionItem* _tmp0_;
	gconstpointer _tmp1_ = NULL;
	GtkTreeIter* _tmp2_;
	GtkTreeIter* _tmp3_;
	GtkTreeIter filter_iter = {0};
	GtkTreeModelFilter* _tmp4_;
	GtkTreeIter* _tmp5_;
	GtkTreeIter _tmp6_ = {0};
	GtkTreeIter _tmp7_;
	gboolean _tmp8_ = FALSE;
	GtkTreeModelFilter* _tmp9_;
	GtkTreeIter _tmp10_;
	GtkTreePath* _tmp11_ = NULL;
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (item != NULL, NULL);
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = item;
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = g_object_get_data ((GObject*) _tmp0_, "iter");
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = __gtk_tree_iter_dup0 ((GtkTreeIter*) _tmp1_);
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iter = _tmp2_;
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = iter;
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp3_ == NULL) {
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		result = NULL;
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_free0 (iter);
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return result;
#line 2076 "collection-view.c"
	}
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = self->priv->model_filter;
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = iter;
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = *_tmp5_;
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = gtk_tree_model_filter_convert_child_iter_to_iter (_tmp4_, &_tmp6_, &_tmp7_);
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	filter_iter = _tmp6_;
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (!_tmp8_) {
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		result = NULL;
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_free0 (iter);
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return result;
#line 2096 "collection-view.c"
	}
#line 236 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = self->priv->model_filter;
#line 236 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = filter_iter;
#line 236 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp11_ = gtk_tree_model_get_path ((GtkTreeModel*) _tmp9_, &_tmp10_);
#line 236 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp11_;
#line 236 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_free0 (iter);
#line 236 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2110 "collection-view.c"
}


static BoxesCollectionItem* boxes_collection_view_get_item_for_iter (BoxesCollectionView* self, GtkTreeIter* iter) {
	BoxesCollectionItem* result = NULL;
	GValue value = {0};
	GtkListStore* _tmp0_;
	GtkTreeIter _tmp1_;
	GValue _tmp2_ = {0};
	GValue _tmp3_;
	BoxesCollectionItem* _tmp4_;
#line 239 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 239 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (iter != NULL, NULL);
#line 242 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model;
#line 242 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = *iter;
#line 242 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get_value ((GtkTreeModel*) _tmp0_, &_tmp1_, (gint) BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &_tmp2_);
#line 242 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	G_IS_VALUE (&value) ? (g_value_unset (&value), NULL) : NULL;
#line 242 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	value = _tmp2_;
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = value;
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _g_object_ref0 (g_value_get_object (&_tmp3_));
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp4_;
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	G_IS_VALUE (&value) ? (g_value_unset (&value), NULL) : NULL;
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2146 "collection-view.c"
}


static BoxesCollectionItem* boxes_collection_view_get_item_for_path (BoxesCollectionView* self, GtkTreePath* path) {
	BoxesCollectionItem* result = NULL;
	GtkTreeIter filter_iter = {0};
	GtkTreeIter iter = {0};
	GtkTreeModelFilter* _tmp0_;
	GtkTreePath* _tmp1_;
	GtkTreeIter _tmp2_ = {0};
	GtkTreeModelFilter* _tmp3_;
	GtkTreeIter _tmp4_;
	GtkTreeIter _tmp5_ = {0};
	GtkTreeIter _tmp6_;
	BoxesCollectionItem* _tmp7_ = NULL;
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (path != NULL, NULL);
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model_filter;
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = path;
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get_iter ((GtkTreeModel*) _tmp0_, &_tmp2_, _tmp1_);
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	filter_iter = _tmp2_;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = self->priv->model_filter;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = filter_iter;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_filter_convert_iter_to_child_iter (_tmp3_, &_tmp5_, &_tmp4_);
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iter = _tmp5_;
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = iter;
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = boxes_collection_view_get_item_for_iter (self, &_tmp6_);
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp7_;
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2190 "collection-view.c"
}


static gboolean boxes_collection_view_model_visible (BoxesCollectionView* self, GtkTreeModel* model, GtkTreeIter* iter) {
	gboolean result = FALSE;
	BoxesCollectionItem* item = NULL;
	GtkTreeIter _tmp0_;
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesCollectionItem* _tmp2_;
	BoxesApp* _tmp3_;
	BoxesCollectionFilter* _tmp4_;
	BoxesCollectionItem* _tmp5_;
	gboolean _tmp6_ = FALSE;
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (model != NULL, FALSE);
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (iter != NULL, FALSE);
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = *iter;
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_collection_view_get_item_for_iter (self, &_tmp0_);
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	item = _tmp1_;
#line 259 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = item;
#line 259 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp2_ == NULL) {
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		result = FALSE;
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (item);
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return result;
#line 2226 "collection-view.c"
	}
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = boxes_app_app;
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _tmp3_->filter;
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = item;
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = boxes_collection_filter_filter (_tmp4_, _tmp5_);
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp6_;
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item);
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2242 "collection-view.c"
}


void boxes_collection_view_refilter (BoxesCollectionView* self) {
	GtkTreeModelFilter* _tmp0_;
#line 265 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model_filter;
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_filter_refilter (_tmp0_);
#line 2254 "collection-view.c"
}


void boxes_collection_view_activate (BoxesCollectionView* self) {
	GtkTreeModelFilter* _tmp0_;
	gint _tmp1_ = 0;
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model_filter;
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = gtk_tree_model_iter_n_children ((GtkTreeModel*) _tmp0_, NULL);
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp1_ == 1) {
#line 2269 "collection-view.c"
		GtkTreePath* path = NULL;
		GtkTreePath* _tmp2_;
		GdMainView* _tmp3_;
		GtkWidget* _tmp4_ = NULL;
		GtkTreePath* _tmp5_;
#line 271 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp2_ = gtk_tree_path_new_from_string ("0");
#line 271 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		path = _tmp2_;
#line 272 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp3_ = self->main_view;
#line 272 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp4_ = gd_main_view_get_generic_view (_tmp3_);
#line 272 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp5_ = path;
#line 272 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		gtk_icon_view_item_activated (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GTK_TYPE_ICON_VIEW) ? ((GtkIconView*) _tmp4_) : NULL, _tmp5_);
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_gtk_tree_path_free0 (path);
#line 2289 "collection-view.c"
	}
}


static gint __lambda34_ (BoxesCollectionView* self, GtkTreeModel* model, GtkTreeIter* a, GtkTreeIter* b) {
	gint result = 0;
	BoxesCollectionItem* item_a = NULL;
	BoxesCollectionItem* item_b = NULL;
	GtkTreeModel* _tmp0_;
	GtkTreeIter _tmp1_;
	GtkTreeModel* _tmp2_;
	GtkTreeIter _tmp3_;
	gboolean _tmp4_ = FALSE;
	BoxesCollectionItem* _tmp5_;
	gboolean _tmp7_;
	BoxesCollectionItem* _tmp8_;
	BoxesCollectionItem* _tmp9_;
	gint _tmp10_ = 0;
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (model != NULL, 0);
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (a != NULL, 0);
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (b != NULL, 0);
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = model;
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = *a;
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get (_tmp0_, &_tmp1_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &item_a, -1);
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = model;
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = *b;
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get (_tmp2_, &_tmp3_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &item_b, -1);
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = item_a;
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp5_ == NULL) {
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp4_ = TRUE;
#line 2332 "collection-view.c"
	} else {
		BoxesCollectionItem* _tmp6_;
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp6_ = item_b;
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp4_ = _tmp6_ == NULL;
#line 2339 "collection-view.c"
	}
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = _tmp4_;
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp7_) {
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		result = 0;
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (item_b);
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (item_a);
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return result;
#line 2353 "collection-view.c"
	}
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = item_a;
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = item_b;
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = boxes_collection_item_compare (_tmp8_, _tmp9_);
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp10_;
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item_b);
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item_a);
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2369 "collection-view.c"
}


static gint ___lambda34__gtk_tree_iter_compare_func (GtkTreeModel* model, GtkTreeIter* a, GtkTreeIter* b, gpointer self) {
	gint result;
	result = __lambda34_ (self, model, a, b);
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2378 "collection-view.c"
}


static void __lambda35_ (BoxesCollectionView* self) {
	BoxesApp* _tmp0_;
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = boxes_app_app;
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject*) _tmp0_, "selected-items");
#line 2388 "collection-view.c"
}


static void ___lambda35__gtk_tree_model_row_deleted (GtkTreeModel* _sender, GtkTreePath* path, gpointer self) {
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda35_ (self);
#line 2395 "collection-view.c"
}


static void __lambda36_ (BoxesCollectionView* self) {
	BoxesApp* _tmp0_;
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = boxes_app_app;
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject*) _tmp0_, "selected-items");
#line 2405 "collection-view.c"
}


static void ___lambda36__gtk_tree_model_row_inserted (GtkTreeModel* _sender, GtkTreePath* path, GtkTreeIter* iter, gpointer self) {
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda36_ (self);
#line 2412 "collection-view.c"
}


static gboolean _boxes_collection_view_model_visible_gtk_tree_model_filter_visible_func (GtkTreeModel* model, GtkTreeIter* iter, gpointer self) {
	gboolean result;
	result = boxes_collection_view_model_visible (self, model, iter);
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2421 "collection-view.c"
}


static void __lambda37_ (BoxesCollectionView* self, GdMainView* view, const gchar* id, GtkTreePath* path) {
	BoxesCollectionItem* item = NULL;
	GtkTreePath* _tmp0_;
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesApp* _tmp2_;
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (view != NULL);
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (id != NULL);
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (path != NULL);
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = path;
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_collection_view_get_item_for_path (self, _tmp0_);
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	item = _tmp1_;
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = boxes_app_app;
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_app_select_item (_tmp2_, item);
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item);
#line 2448 "collection-view.c"
}


static void ___lambda37__gd_main_view_item_activated (GdMainView* _sender, const gchar* object, GtkTreePath* p0, gpointer self) {
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda37_ (self, _sender, object, p0);
#line 2455 "collection-view.c"
}


static void __lambda54_ (BoxesCollectionView* self) {
	GdMainView* _tmp0_;
	BoxesApp* _tmp1_;
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->main_view;
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) _tmp0_);
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_app_app;
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject*) _tmp1_, "selected-items");
#line 2470 "collection-view.c"
}


static void ___lambda54__gd_main_view_view_selection_changed (GdMainView* _sender, gpointer self) {
#line 317 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda54_ (self);
#line 2477 "collection-view.c"
}


static void __lambda55_ (BoxesCollectionView* self) {
	BoxesApp* _tmp0_;
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = boxes_app_app;
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_app_set_selection_mode (_tmp0_, TRUE);
#line 2487 "collection-view.c"
}


static void ___lambda55__gd_main_view_selection_mode_request (GdMainView* _sender, gpointer self) {
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda55_ (self);
#line 2494 "collection-view.c"
}


static void boxes_collection_view_setup_view (BoxesCollectionView* self) {
	GtkListStore* _tmp0_;
	GtkListStore* _tmp1_;
	GtkListStore* _tmp2_;
	GtkListStore* _tmp3_;
	GtkListStore* _tmp4_;
	GtkListStore* _tmp5_;
	GtkTreeModelFilter* _tmp6_;
	GtkTreeModelFilter* _tmp7_;
	GObject* _tmp8_ = NULL;
	GObject* _tmp9_;
	GdMainView* _tmp10_;
	GdMainView* _tmp11_;
	GdMainView* _tmp12_;
	GtkTreeModelFilter* _tmp13_;
	GdMainView* _tmp14_;
	GtkStyleContext* _tmp15_ = NULL;
	GdMainView* _tmp16_;
	GdMainView* _tmp17_;
	GdMainView* _tmp18_;
	GdMainView* _tmp19_;
	GdMainView* _tmp20_;
	GtkClutterActor* _tmp21_;
	GtkClutterActor* _tmp22_;
	GtkWidget* _tmp23_ = NULL;
	GtkStyleContext* _tmp24_ = NULL;
	GtkClutterActor* _tmp25_;
	GtkClutterActor* _tmp26_;
	GtkClutterActor* _tmp27_;
	GtkClutterActor* _tmp28_;
	GtkClutterActor* _tmp29_;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = gtk_list_store_new ((gint) BOXES_COLLECTION_VIEW_MODEL_COLUMNS_LAST, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, GDK_TYPE_PIXBUF, G_TYPE_LONG, G_TYPE_BOOLEAN, BOXES_TYPE_COLLECTION_ITEM);
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->model);
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv->model = _tmp0_;
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = self->priv->model;
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_sortable_set_default_sort_func ((GtkTreeSortable*) _tmp1_, ___lambda34__gtk_tree_iter_compare_func, g_object_ref (self), g_object_unref);
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = self->priv->model;
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable*) _tmp2_, GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID, GTK_SORT_ASCENDING);
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = self->priv->model;
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GtkTreeModel*) _tmp3_, "row-deleted", (GCallback) ___lambda35__gtk_tree_model_row_deleted, self, 0);
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = self->priv->model;
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GtkTreeModel*) _tmp4_, "row-inserted", (GCallback) ___lambda36__gtk_tree_model_row_inserted, self, 0);
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = self->priv->model;
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = (GtkTreeModelFilter*) gtk_tree_model_filter_new ((GtkTreeModel*) _tmp5_, NULL);
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->model_filter);
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv->model_filter = _tmp6_;
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = self->priv->model_filter;
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_filter_set_visible_func (_tmp7_, _boxes_collection_view_model_visible_gtk_tree_model_filter_visible_func, g_object_ref (self), g_object_unref);
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = g_object_new (gd_main_view_get_type (), NULL);
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = G_IS_INITIALLY_UNOWNED (_tmp8_) ? g_object_ref_sink (_tmp8_) : _tmp8_;
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, gd_main_view_get_type ()) ? ((GdMainView*) _tmp9_) : NULL;
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp10_ == NULL) {
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (_tmp9_);
#line 2575 "collection-view.c"
	}
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->main_view);
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->main_view = _tmp10_;
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp11_ = self->main_view;
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gd_main_view_set_view_type (_tmp11_, GD_MAIN_VIEW_ICON);
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp12_ = self->main_view;
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp13_ = self->priv->model_filter;
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gd_main_view_set_model (_tmp12_, (GtkTreeModel*) _tmp13_);
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14_ = self->main_view;
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp15_ = gtk_widget_get_style_context ((GtkWidget*) _tmp14_);
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_style_context_add_class (_tmp15_, "boxes-icon-view");
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp16_ = self->main_view;
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object (_tmp16_, "item-activated", (GCallback) ___lambda37__gd_main_view_item_activated, self, 0);
#line 317 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp17_ = self->main_view;
#line 317 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object (_tmp17_, "view-selection-changed", (GCallback) ___lambda54__gd_main_view_view_selection_changed, self, 0);
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp18_ = self->main_view;
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object (_tmp18_, "selection-mode-request", (GCallback) ___lambda55__gd_main_view_selection_mode_request, self, 0);
#line 324 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp19_ = self->main_view;
#line 324 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp19_);
#line 326 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp20_ = self->main_view;
#line 326 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp21_ = (GtkClutterActor*) gtk_clutter_actor_new_with_contents ((GtkWidget*) _tmp20_);
#line 326 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_ref_sink (_tmp21_);
#line 326 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->gtkactor);
#line 326 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv->gtkactor = _tmp21_;
#line 327 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp22_ = self->priv->gtkactor;
#line 327 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp23_ = gtk_clutter_actor_get_widget (_tmp22_);
#line 327 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp24_ = gtk_widget_get_style_context (_tmp23_);
#line 327 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_style_context_add_class (_tmp24_, "boxes-bg");
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp25_ = self->priv->gtkactor;
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	clutter_actor_set_name ((ClutterActor*) _tmp25_, "collection-view");
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp26_ = self->priv->gtkactor;
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	clutter_actor_set_x_align ((ClutterActor*) _tmp26_, CLUTTER_ACTOR_ALIGN_FILL);
#line 330 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp27_ = self->priv->gtkactor;
#line 330 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	clutter_actor_set_y_align ((ClutterActor*) _tmp27_, CLUTTER_ACTOR_ALIGN_FILL);
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp28_ = self->priv->gtkactor;
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	clutter_actor_set_x_expand ((ClutterActor*) _tmp28_, TRUE);
#line 332 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp29_ = self->priv->gtkactor;
#line 332 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	clutter_actor_set_y_expand ((ClutterActor*) _tmp29_, TRUE);
#line 2651 "collection-view.c"
}


static Block13Data* block13_data_ref (Block13Data* _data13_) {
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_atomic_int_inc (&_data13_->_ref_count_);
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return _data13_;
#line 2660 "collection-view.c"
}


static void block13_data_unref (void * _userdata_) {
	Block13Data* _data13_;
	_data13_ = (Block13Data*) _userdata_;
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (g_atomic_int_dec_and_test (&_data13_->_ref_count_)) {
#line 2669 "collection-view.c"
		BoxesCollectionView * self;
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		self = _data13_->self;
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (self);
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_slice_free (Block13Data, _data13_);
#line 2677 "collection-view.c"
	}
}


static gboolean __lambda63_ (Block13Data* _data13_, GtkTreeModel* filter_model, GtkTreePath* filter_path, GtkTreeIter* filter_iter) {
	BoxesCollectionView * self;
	gboolean result = FALSE;
	GtkTreeIter iter = {0};
	GtkTreeModelFilter* _tmp0_;
	GtkTreeIter _tmp1_;
	GtkTreeIter _tmp2_ = {0};
	gboolean selected = FALSE;
	BoxesSelectionCriteria _tmp3_;
	GtkListStore* _tmp14_;
	GtkTreeIter _tmp15_;
	gboolean _tmp16_;
#line 339 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data13_->self;
#line 339 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (filter_model != NULL, FALSE);
#line 339 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (filter_path != NULL, FALSE);
#line 339 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (filter_iter != NULL, FALSE);
#line 341 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model_filter;
#line 341 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = *filter_iter;
#line 341 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_filter_convert_iter_to_child_iter (_tmp0_, &_tmp2_, &_tmp1_);
#line 341 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iter = _tmp2_;
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = _data13_->selection;
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	switch (_tmp3_) {
#line 2714 "collection-view.c"
		default:
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_SELECTION_CRITERIA_ALL:
#line 2718 "collection-view.c"
		{
#line 346 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			selected = TRUE;
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			break;
#line 2724 "collection-view.c"
		}
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_SELECTION_CRITERIA_NONE:
#line 2728 "collection-view.c"
		{
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			selected = FALSE;
#line 350 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			break;
#line 2734 "collection-view.c"
		}
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_SELECTION_CRITERIA_RUNNING:
#line 2738 "collection-view.c"
		{
			BoxesCollectionItem* item = NULL;
			GtkListStore* _tmp4_;
			GtkTreeIter _tmp5_;
			gboolean _tmp6_ = FALSE;
			gboolean _tmp7_ = FALSE;
			BoxesCollectionItem* _tmp8_;
			gboolean _tmp10_;
			gboolean _tmp13_;
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp4_ = self->priv->model;
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp5_ = iter;
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			gtk_tree_model_get ((GtkTreeModel*) _tmp4_, &_tmp5_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &item, -1);
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp8_ = item;
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			if (_tmp8_ != NULL) {
#line 2758 "collection-view.c"
				BoxesCollectionItem* _tmp9_;
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp9_ = item;
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp7_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, BOXES_TYPE_MACHINE);
#line 2764 "collection-view.c"
			} else {
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp7_ = FALSE;
#line 2768 "collection-view.c"
			}
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp10_ = _tmp7_;
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			if (_tmp10_) {
#line 2774 "collection-view.c"
				BoxesCollectionItem* _tmp11_;
				gboolean _tmp12_ = FALSE;
#line 355 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp11_ = item;
#line 355 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp12_ = boxes_machine_is_running (G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp11_) : NULL);
#line 355 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp6_ = _tmp12_;
#line 2783 "collection-view.c"
			} else {
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp6_ = FALSE;
#line 2787 "collection-view.c"
			}
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp13_ = _tmp6_;
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			selected = _tmp13_;
#line 356 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (item);
#line 356 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			break;
#line 2797 "collection-view.c"
		}
	}
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14_ = self->priv->model;
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp15_ = iter;
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp16_ = selected;
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp14_, &_tmp15_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED, _tmp16_, -1);
#line 359 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = FALSE;
#line 359 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2812 "collection-view.c"
}


static gboolean ___lambda63__gtk_tree_model_foreach_func (GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter, gpointer self) {
	gboolean result;
	result = __lambda63_ (self, model, path, iter);
#line 339 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2821 "collection-view.c"
}


void boxes_collection_view_select (BoxesCollectionView* self, BoxesSelectionCriteria selection) {
	Block13Data* _data13_;
	BoxesSelectionCriteria _tmp0_;
	BoxesApp* _tmp1_;
	GtkTreeModelFilter* _tmp2_;
	GdMainView* _tmp3_;
	BoxesApp* _tmp4_;
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data13_ = g_slice_new0 (Block13Data);
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data13_->_ref_count_ = 1;
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data13_->self = g_object_ref (self);
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = selection;
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data13_->selection = _tmp0_;
#line 337 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_app_app;
#line 337 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_app_set_selection_mode (_tmp1_, TRUE);
#line 339 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = self->priv->model_filter;
#line 339 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_foreach ((GtkTreeModel*) _tmp2_, ___lambda63__gtk_tree_model_foreach_func, _data13_);
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = self->main_view;
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) _tmp3_);
#line 362 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = boxes_app_app;
#line 362 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject*) _tmp4_, "selected-items");
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	block13_data_unref (_data13_);
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data13_ = NULL;
#line 2864 "collection-view.c"
}


static ClutterActor* boxes_collection_view_real_get_actor (BoxesUI* base) {
	ClutterActor* result;
	BoxesCollectionView* self;
	GtkClutterActor* _tmp0_;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = (BoxesCollectionView*) base;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->gtkactor;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = (ClutterActor*) _tmp0_;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2880 "collection-view.c"
}


BoxesCategory* boxes_collection_view_get_category (BoxesCollectionView* self) {
	BoxesCategory* result;
	BoxesCategory* _tmp0_;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->_category;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp0_;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2895 "collection-view.c"
}


void boxes_collection_view_set_category (BoxesCollectionView* self, BoxesCategory* value) {
	BoxesCategory* _tmp0_;
	BoxesCategory* _tmp1_;
#line 18 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = value;
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->_category);
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv->_category = _tmp1_;
#line 18 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject *) self, "category");
#line 2914 "collection-view.c"
}


void boxes_collection_view_set_visible (BoxesCollectionView* self, gboolean value) {
	GdMainView* _tmp0_;
	gboolean _tmp1_;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->main_view;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = value;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp0_, _tmp1_);
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject *) self, "visible");
#line 2931 "collection-view.c"
}


static void boxes_collection_view_class_init (BoxesCollectionViewClass * klass) {
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_parent_class = g_type_class_peek_parent (klass);
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_type_class_add_private (klass, sizeof (BoxesCollectionViewPrivate));
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	BOXES_UI_CLASS (klass)->ui_state_changed = boxes_collection_view_real_ui_state_changed;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	BOXES_UI_CLASS (klass)->get_actor = boxes_collection_view_real_get_actor;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_collection_view_get_property;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_collection_view_set_property;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_collection_view_finalize;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_COLLECTION_VIEW_ACTOR, g_param_spec_object ("actor", "actor", "actor", clutter_actor_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_COLLECTION_VIEW_CATEGORY, g_param_spec_object ("category", "category", "category", BOXES_TYPE_CATEGORY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_COLLECTION_VIEW_VISIBLE, g_param_spec_boolean ("visible", "visible", "visible", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
#line 2956 "collection-view.c"
}


static void boxes_collection_view_instance_init (BoxesCollectionView * self) {
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv = BOXES_COLLECTION_VIEW_GET_PRIVATE (self);
#line 2963 "collection-view.c"
}


static void boxes_collection_view_finalize (GObject* obj) {
	BoxesCollectionView * self;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->gtkactor);
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->_category);
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->main_view);
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->model);
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->model_filter);
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	G_OBJECT_CLASS (boxes_collection_view_parent_class)->finalize (obj);
#line 2983 "collection-view.c"
}


GType boxes_collection_view_get_type (void) {
	static volatile gsize boxes_collection_view_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_collection_view_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesCollectionViewClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_collection_view_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesCollectionView), 0, (GInstanceInitFunc) boxes_collection_view_instance_init, NULL };
		GType boxes_collection_view_type_id;
		boxes_collection_view_type_id = g_type_register_static (BOXES_TYPE_UI, "BoxesCollectionView", &g_define_type_info, 0);
		g_once_init_leave (&boxes_collection_view_type_id__volatile, boxes_collection_view_type_id);
	}
	return boxes_collection_view_type_id__volatile;
}


static void _vala_boxes_collection_view_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesCollectionView * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView);
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	switch (property_id) {
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_COLLECTION_VIEW_ACTOR:
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_value_set_object (value, boxes_ui_get_actor ((BoxesUI*) self));
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_COLLECTION_VIEW_CATEGORY:
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_value_set_object (value, boxes_collection_view_get_category (self));
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 3016 "collection-view.c"
		default:
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 3022 "collection-view.c"
	}
}


static void _vala_boxes_collection_view_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesCollectionView * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView);
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	switch (property_id) {
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_COLLECTION_VIEW_CATEGORY:
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		boxes_collection_view_set_category (self, g_value_get_object (value));
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_COLLECTION_VIEW_VISIBLE:
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		boxes_collection_view_set_visible (self, g_value_get_boolean (value));
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 3044 "collection-view.c"
		default:
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 3050 "collection-view.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 3058 "collection-view.c"
		int i;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
				destroy_func (((gpointer*) array)[i]);
#line 3066 "collection-view.c"
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_free (array);
#line 3078 "collection-view.c"
}



